@@ -25,14 +25,22 @@ PYTHON_DEFAULT_VERSION = PYTHON_VERSIONS[-1]
 
 PY_PATHS = ['b2', 'test', 'noxfile.py', 'setup.py']
 
+SYSTEM = platform.system().lower()
+
 REQUIREMENTS_FORMAT = ['yapf==0.27']
 REQUIREMENTS_LINT = ['yapf==0.27', 'pyflakes==2.2.0', 'pytest==6.1.1', 'liccheck==0.4.7']
 REQUIREMENTS_TEST = ['pytest==6.1.1', 'pytest-cov==2.10.1']
 REQUIREMENTS_BUILD = ['setuptools>=20.2']
+REQUIREMENTS_BUNDLE = ['pyinstaller']
+if SYSTEM == 'linux':
+    REQUIREMENTS_BUNDLE.extend(['patchelf-wrapper', 'staticx'])
 
 OSX_BUNDLE_IDENTIFIER = 'com.backblaze.b2'
 OSX_BUNDLE_ENTITLEMENTS = 'contrib/macos/entitlements.plist'
 
+WINDOWS_TIMESTAMP_SERVER = 'http://timestamp.digicert.com'
+WINDOWS_SIGNTOOL_PATH = 'C:/Program Files (x86)/Windows Kits/10/bin/10.0.17763.0/x86/signtool.exe'
+
 nox.options.reuse_existing_virtualenvs = True
 nox.options.sessions = [
     'lint',
@@ -167,9 +175,6 @@ def build(session):
         asset_path = glob('dist/*')[0]
         print('::set-output name=asset_path::', asset_path, sep='')
 
-        asset_name = os.path.basename(asset_path)
-        print('::set-output name=asset_name::', asset_name, sep='')
-
         version = os.environ['GITHUB_REF'].replace('refs/tags/v', '')
         print('::set-output name=version::', version, sep='')
 
@@ -177,53 +182,104 @@ def build(session):
 @nox.session(python=PYTHON_DEFAULT_VERSION)
 def bundle(session):
     """Bundle the distribution."""
-    session.install('pyinstaller')
+    session.install(*REQUIREMENTS_BUNDLE)
     session.run('rm', '-rf', 'build', 'dist', 'b2.egg-info', external=True)
     install_myself(session)
 
-    system = platform.system().lower()
-
-    if system == 'darwin':
+    if SYSTEM == 'darwin':
         session.posargs.extend(['--osx-bundle-identifier', OSX_BUNDLE_IDENTIFIER])
 
     session.run('pyinstaller', '--onefile', *session.posargs, 'b2.spec')
 
+    if SYSTEM == 'linux':
+        session.run(
+            'staticx', '--no-compress', '--strip', '--loglevel', 'INFO', 'dist/b2', 'dist/b2-static'
+        )
+        session.run('mv', '-f', 'dist/b2-static', 'dist/b2', external=True)
+
     # Set outputs for GitHub Actions
     if CI:
         asset_path = glob('dist/*')[0]
         print('::set-output name=asset_path::', asset_path, sep='')
 
-        name, ext = os.path.splitext(os.path.basename(asset_path))
-        asset_name = '{}-{}{}'.format(name, system, ext)
-        print('::set-output name=asset_name::', asset_name, sep='')
-
 
 @nox.session(python=False)
 def sign(session):
-    """Sign the bundled distribution (OSX only)."""
-    system = platform.system().lower()
+    """Sign the bundled distribution (macOS and Windows only)."""
 
-    if system != 'darwin':
-        session.skip('signing process is for OSX only')
+    def sign_darwin(cert_name):
+        session.run('security', 'find-identity', external=True)
+        session.run(
+            'codesign',
+            '--deep',
+            '--force',
+            '--verbose',
+            '--timestamp',
+            '--identifier',
+            OSX_BUNDLE_IDENTIFIER,
+            '--entitlements',
+            OSX_BUNDLE_ENTITLEMENTS,
+            '--options',
+            'runtime',
+            '--sign',
+            cert_name,
+            'dist/b2',
+            external=True
+        )
+        session.run('codesign', '--verify', '--verbose', 'dist/b2', external=True)
 
-    session.run('security', 'find-identity', external=True)
-    session.run(
-        'codesign',
-        '--deep',
-        '--force',
-        '--verbose',
-        '--timestamp',
-        '--identifier',
-        OSX_BUNDLE_IDENTIFIER,
-        '--entitlements',
-        OSX_BUNDLE_ENTITLEMENTS,
-        '--options',
-        'runtime',
-        *session.posargs,
-        'dist/b2',
-        external=True
-    )
-    session.run('codesign', '--verify', '--verbose', 'dist/b2', external=True)
+    def sign_windows(cert_file, cert_password):
+        session.run('certutil', '-f', '-p', cert_password, '-importpfx', cert_file)
+        session.run(
+            WINDOWS_SIGNTOOL_PATH,
+            'sign',
+            '/f',
+            cert_file,
+            '/p',
+            cert_password,
+            '/tr',
+            WINDOWS_TIMESTAMP_SERVER,
+            '/td',
+            'sha256',
+            '/fd',
+            'sha256',
+            'dist/b2.exe',
+            external=True
+        )
+        session.run(WINDOWS_SIGNTOOL_PATH, 'verify', '/pa', '/all', 'dist/b2.exe', external=True)
+
+    if SYSTEM == 'darwin':
+        try:
+            certificate_name, = session.posargs
+        except ValueError:
+            session.error('pass the certificate name as a positional argument')
+            return
+
+        sign_darwin(certificate_name)
+    elif SYSTEM == 'windows':
+        try:
+            certificate_file, certificate_password = session.posargs
+        except ValueError:
+            session.error('pass the certificate file and the password as positional arguments')
+            return
+
+        sign_windows(certificate_file, certificate_password)
+    elif SYSTEM == 'linux':
+        session.log('signing is not supported for Linux')
+    else:
+        session.error('unrecognized platform: {}'.format(SYSTEM))
+
+    # Append OS name to the binary
+    asset_old_path = glob('dist/*')[0]
+    name, ext = os.path.splitext(os.path.basename(asset_old_path))
+    asset_path = 'dist/{}-{}{}'.format(name, SYSTEM, ext)
+
+    session.run('mv', '-f', asset_old_path, asset_path, external=True)
+
+    # Set outputs for GitHub Actions
+    if CI:
+        asset_path = glob('dist/*')[0]
+        print('::set-output name=asset_path::', asset_path, sep='')
 
 
 @nox.session(python=PYTHON_DEFAULT_VERSION)
